@@ -25,7 +25,7 @@ class Storage(driver.Base):
         logger.info("==========================>jss_bucket:%s" % config.jss_bucket)
         logger.info("==========================>jss_domain:%s" % config.jss_domain)
         
-        self._jss = JssClient(None, self._access_key, self._secret_key, self._domain, None)
+        self._jss = JssClient(None, self._access_key, self._secret_key, self._domain, "80")
         
     def _init_path(self, path=None):
         if path:
@@ -53,8 +53,6 @@ class Storage(driver.Base):
         path1 = self._init_path(path)
         output = StringIO.StringIO()
         try:
-            logger.info("get_content self._bucket:%s" % self._bucket)
-            logger.info("get_content path1:%s" % path1)
             object_instance = self._jss.bucket(self._bucket).object(path1)
             res = object_instance.download_flow()
             logger.info("get_content res:%s" % res)
